# **Developer guide**

Welcome to the **SplitterMR Python API** reference.

![SplitterMR architecture diagram](../assets/splitter_mr_architecture_diagram.svg#gh-light-mode-only)

![SplitterMR architecture diagram](../assets/splitter_mr_architecture_diagram_white.svg#gh-dark-mode-only)

## **Documentation**

### [Vision Model component](./model.md)

Extend the reader capabilities using VLMs (Visual Language Models) to analyze visual content from your documents.

### [Reader component](./reader.md)

Use different reading methods to process your files before splitting them.

### [Splitter component](./splitter.md)

Implement several splitting strategies based on the type of document and use case.

### [Embedding component](./embedding.md)

Implement encoder models from different providers to perform Semantic Splitting.
